@@ -55,7 +55,7 @@ use RT::Shredder;
 
 package RT::Extension::MergeUsers;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 =head1 NAME
 
@@ -63,7 +63,7 @@ RT::Extension::MergeUsers - Merges two users into the same effective user
  
 =head1 RT VERSION
 
-Works with RT 4.0, 4.2 and 4.4.
+Works with RT 4.0, 4.2, 4.4, 5.0.
 
 =head1 DESCRIPTION
 
@@ -92,7 +92,7 @@ Be sure to also read L</UPGRADING> if you are upgrading.
 
 May need root permissions
 
-=item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>
+=item Edit your F</opt/rt5/etc/RT_SiteConfig.pm>
 
 If you are using RT 4.2 or greater, add this line:
 
@@ -106,7 +106,7 @@ or add C<RT::Extension::MergeUsers> to your existing C<@Plugins> line.
 
 =item Clear your mason cache
 
-    rm -rf /opt/rt4/var/mason_data/obj
+    rm -rf /opt/rt5/var/mason_data/obj
 
 =item Restart your webserver
 
@@ -456,6 +456,28 @@ sub SetDisabled {
     return ($ret, $msg);
 }
 
+my $orig_has_right = \&RT::Principal::HasRight;
+*HasRight = sub {
+    my $self = shift;
+    my $ret = $orig_has_right->( $self, @_ );
+    return $ret if $ret || $self->IsGroup;
+
+    if ( my $merged_users = $self->Object->FirstAttribute('MergedUsers') ) {
+        for my $id ( @{ $merged_users->Content || [] } ) {
+            my $principal = RT::Principal->new( $self->CurrentUser );
+            $principal->Load($id);
+            if ( $principal->Id ) {
+                my $ret = $orig_has_right->( $principal, @_ );
+                return $ret if $ret;
+            }
+            else {
+                RT->Logger->warning("Couldn't load principal #$id");
+            }
+        }
+    }
+    return 0;
+};
+
 {
     package RT::Group;
     my $orig_delete_member = \&RT::Group::DeleteMember;
